@@ -61,7 +61,7 @@ def create_configuration(
 
 # Example usage:
 if __name__ == "__main__":
-    CONFIG = create_configuration(file_path='appsettings.json', required_components=["redis", "kafka", "sql"])
+    CONFIG = create_configuration(file_path='appsettings.json', required_components=["clickhouse", "kafka", "sql"])
     print(CONFIG.__dict__)
     SERVICE_NAME = "FACEBOOK_PAGE_INSIGHT_READER_SERVICE"
     IS_ASYNC_LOGGER = CONFIG.__dict__.get('_is_async_logger', False)
