@@ -43,6 +43,9 @@ async def configure_google_chat(service_name: str, configuration: Dict[str, Any]
     g_chat_hook = extra_properties.get("g_chat_webhook")
     error_gchat_hook = extra_properties.get("error_g_chat_webhook")
     logger.info(f"Google Chat async mode: {is_async_gchat}")
+    logger.info(f"Google Chat webhook: {g_chat_hook}")
+    logger.info(f"Error Google Chat webhook: {error_gchat_hook}")
+
     g_chat = setup_google_chat_messenger(
         service_name, g_chat_hook, error_gchat_hook, environ,
         is_async_gchat, log_enabled, logger
@@ -136,9 +139,9 @@ async def configure_db_auth(configuration: Dict[str, Any], database_name: str) -
     Expected keys: sql_server_ip, sql_user_name, sql_pass_word.
     The database name is passed as a parameter.
     """
-    sql_server_ip = configuration.get("sql_server_ip")
-    sql_user_name = configuration.get("sql_user_name")
-    sql_pass_word = configuration.get("sql_pass_word")
+    sql_server_ip = configuration.get("_sql_server_ip")
+    sql_user_name = configuration.get("_sql_user_name")
+    sql_pass_word = configuration.get("_sql_pass_word")
 
     # Extract host and port from sql_server_ip (assuming it's in "IP,PORT" format)
     if "," in sql_server_ip:
