@@ -5,8 +5,9 @@ from jsonschema import validate, ValidationError, SchemaError
 from locobuzz_python_configuration.utils_functions import add_extra_properties_to_schema
 
 properties: Dict[str, List[str]] = {
-    "sql": ["sql_user_name", "sql_server_ip", "sql_pass_word"],
-    "clickhouse": ["clickhouse_host", "clickhouse_port"],
+    "sql": ["sql_user_name", "sql_server_ip", "sql_pass_word", "connection_string"],
+    # Now supports connection string
+    "clickhouse": ["clickhouse_host", "clickhouse_port", "clickhouse_username", "clickhouse_password"],
     "aws": ["aws_access_key", "aws_secret_key"],
     "elastic": ["elastic_host", "elastic_username", "elastic_password"],
     "redis": ["redis_host"],
@@ -93,6 +94,7 @@ class ConfigurationBuilder:
                 "sql_user_name": {"type": "string"},
                 "sql_server_ip": {"type": "string"},
                 "sql_pass_word": {"type": "string"},
+                "connection_string": {"type": "string"},  # New property for connection string
                 "clickhouse_host": {"type": "string"},
                 "clickhouse_port": {"type": "string"},
                 "clickhouse_username": {"type": "string"},
@@ -100,14 +102,10 @@ class ConfigurationBuilder:
                 "elastic_host": {"type": "string"},
                 "elastic_username": {"type": "string"},
                 "elastic_password": {"type": "string"},
-                "elastic_mention_index_name": {"type": "string"},
-                "elastic_author_index_name": {"type": "string"},
-                "opensearch_python_service_endpoint": {"type": "string"},
                 "aws_access_key": {"type": "string"},
                 "aws_secret_key": {"type": "string"},
                 "s3_bucket_name": {"type": "string"},
                 "aws_s3_base_url": {"type": "string"},
-                "service_ng_api": {"type": "string"},
                 "broker": {"type": "string"},
                 "read_topic": {"type": "string"},
                 "dead_letter_topic_name": {"type": "string"},
@@ -124,8 +122,15 @@ class ConfigurationBuilder:
 
     def validate_required_components(self, data: Dict[str, Any]) -> None:
         if "sql" in self.required_components:
-            if not data.get('sql_user_name') or not data.get('sql_server_ip') or not data.get('sql_pass_word'):
-                raise InvalidConfigurationError("Missing SQL configuration properties")
+            sql_user = data.get('sql_user_name')
+            sql_ip = data.get('sql_server_ip')
+            sql_pass = data.get('sql_pass_word')
+            sql_conn_str = data.get('connection_string')
+
+            # Ensure at least one method is used (either individual fields or connection string)
+            if not sql_conn_str and (not sql_user or not sql_ip or not sql_pass):
+                raise InvalidConfigurationError(
+                    "Missing SQL configuration properties. Either provide (sql_user_name, sql_server_ip, sql_pass_word) OR sql_connection_string.")
 
         if "clickhouse" in self.required_components:
             if not data.get('clickhouse_host') or not data.get('clickhouse_port'):
