@@ -1,12 +1,15 @@
+from typing import Any, Dict
+
+
 class InvalidKafkaConfigurationError(Exception):
     pass
 
 
 class KafkaConfigurationBuilder:
-    def __init__(self, config):
+    def __init__(self, config: Any) -> None:
         self._config = config
 
-    def build(self, data):
+    def build(self, data: Dict[str, Any]) -> None:
         self._config._broker = data.get('broker')
         self._config._push_topic = data.get('push_topic')
         self._config._read_topic = data.get('read_topic')
